require_relative 'concerns/fullcalendar_utility.rb'
require_relative 'concerns/zoom_utility.rb'
require_relative '../models/concerns/login_module.rb'

class ApplicationBaseController < ActionController::Base
  include CommonEngine::FullcalendarUtility
  include CommonEngine::ZoomUtility

  protect_from_forgery with: :exception

  SELECT_LANGUAGE_MESSAGE = 'Select Language'.freeze

  if !Rails.env.development?
    rescue_from Exception, with: :handle_500_fatal
    rescue_from StandardError, with: :handle_500
    rescue_from ActiveRecord::RecordNotFound, AbstractController::ActionNotFound, with: :handle_404
  end

  def handle_500_fatal(exception = nil)
    logger.fatal exception.message if exception
    render_error 500
  end
  def handle_500(exception = nil)
    logger.error exception.message if exception
    render_error 500
  end
  def handle_404(exception = nil)
    logger.warn exception.message if exception
    render_error 404
  end
  # called from config/initializers/application_controller_renderer.rb
  def handle_uncatchable
    logger.error "Requested: #{request.env['action_dispatch.original_path']}"
    logger.error request.env['action_dispatch.exception']
    status = request.path[1..-1].to_i
    render_error 500
  end

  private
    def render_error(status)
      if request.xhr? || params[:format] == :json
        render :json, status: status
      else
        set_locale
        render template: "errors/error_#{status}", formats: :html, status: status, layout: 'application_base', content_type: 'text/html'
      end
    end
    def set_locale
      I18n.locale = locale
      @locale_map = {}
      I18n.available_locales.each do |available_locale|
        @locale_map[available_locale.to_s] = t('common.language', locale: available_locale)
      end
    end
    def locale
      @locale ||= params[:locale] || I18n.default_locale
    end
    def default_url_options(options={})
      options.merge(locale: locale)
    end
end
