require 'net/http'
require 'net/https'
require 'uri'
require 'jwt'

module CommonEngine
  module ZoomUtility
    extend ActiveSupport::Concern

    ZOOM_PASSWORD = 'asp123'.freeze
    ZOOM_USER_LAST_NAME = 'AfterSchool-Project'.freeze
    ZOOM_DATETIME_FORMAT = "%Y-%m-%d'T'%H:%M:%S'Z'".freeze
    ZOOM_DURATION = 90.freeze

    # see https://zoom.github.io/api/?shell#create-a-user for more information
    def create_zoom_user(email)
      url = 'https://api.zoom.us/v2/users'
      data = {
        action: 'create',
        user_info: {
          email: email,
          password: ZOOM_PASSWORD,
          type: 1
        }
      }
      return ActiveSupport::JSON.decode(send_ssl_post(url, data).body)
    end

    def delete_zoom_user(email)
      url = 'https://api.zoom.us/v2/users/' + email
      data = {
        action: 'delete'
      }
      send_ssl_delete(url, data).body
    end

    # see https://zoom.github.io/api/?shell#create-a-meeting for more information
    def create_meeting(zoom_user_id, chapter_id, start_datetime)
      url = 'https://api.zoom.us/v2/users/' + zoom_user_id + '/meetings'
      chapter = CommonEngine::Chapter.joins(:course).includes(:course).find(chapter_id)
      data = {
        topic: chapter.course.name + ' ' + chapter.name,
        type: 2,
        start_time: start_datetime.strftime(ZOOM_DATETIME_FORMAT),
        duration: ZOOM_DURATION,
        timezone: t('common.time_zone'),
        password: ZOOM_PASSWORD,
        settings: {
          host_video: false,
          participant_video: false,
          join_before_host: true,
          watermark: true,
          approval_type: 2,
          audio: 'both',
          auto_recording: 'none',
          enforce_login: false
        }
      }
      return ActiveSupport::JSON.decode(send_ssl_post(url, data).body)
    end

    private
      def send_ssl_post(url, data={})
        return send_ssl(url, data, 'POST')
      end

      def send_ssl_put(url, data={})
        return send_ssl(url, data, 'PUT')
      end

      def send_ssl_delete(url, data={})
        return send_ssl(url, data, 'DELETE')
      end

      def send_ssl(url, data, method)
        uri = URI.parse(url)
        https = Net::HTTP.new(uri.host, uri.port)
        https.use_ssl = true
        req = Net::HTTP::Post.new(uri.request_uri) if method == 'POST'
        req = Net::HTTP::PUT.new(uri.request_uri) if method == 'PUT'
        req = Net::HTTP::Delete.new(uri.request_uri) if method == 'DELETE'

        # set header
        req['Content-Type'] = 'application/json'
        req['Authorization'] = 'Bearer ' + get_token

        # set body
        req.body = data.to_json
        return https.request(req)
      end

      def send_get(url, req_param_hash={})
        param_string = '?'
        req_param_hash.each {|key, value| param_string += key.to_s + '=' + value.to_s}
        param_string += 'access_token=' + get_token
        uri = URI.parse(url + req_params)
        return Net::HTTP.get(uri)
      end

      def get_token
        api_key = Rails.application.credentials.zoom[:api_key]
        api_secret = Rails.application.credentials.zoom[:api_secret]
        payload = {
          iss: api_key,
          exp: Time.now.utc.to_i + 60
        }
        return JWT.encode payload, api_secret, 'HS256'
      end
  end
end
