require_relative '../concerns/image_uploader.rb'

module CommonEngine
  class Chapter < ApplicationRecord
    self.table_name = 'mst_chapters'
    default_scope -> {where(valid_flg: false)}

    belongs_to :course, class_name: 'CommonEngine::Course', primary_key: 'id', foreign_key: 'course_id'
    has_many :schedules, class_name: 'CommonEngine::Schedule', foreign_key: 'chapter_id'

    scope :search_with_idle_id, -> idle_id {
      schedules = CommonEngine::Schedule.arel_table
      join_condition = arel_table.join(schedules, Arel::Nodes::OuterJoin).on(
                      Arel::Nodes::And.new([arel_table[:id].eq(schedules[:chapter_id]),
                      schedules[:idle_id].eq(idle_id)])).join_sources
      joins(join_condition)
    }

    mount_uploader :file_name, CommonEngine::ImageUploader

    def get_unescaped_file_name
      URI.unescape(self.file_name.to_s.gsub(/.*\//, ''))
    end
  end
end
