require_relative '../concerns/login_module.rb'
require_relative '../concerns/image_uploader.rb'

module CommonEngine
  class Idle < ApplicationRecord
    include CommonEngine::LoginModule

    default_scope -> {where(valid_flg: false)}

    has_secure_password validations: true
    validates :login_id, presence: true, uniqueness: true

    has_one :favorite
    has_many :idle_login_history

    belongs_to :group, class_name: 'CommonEngine::Group', primary_key: 'id', foreign_key: 'group_id', optional: true

    scope :search_with_favorited_user_id, -> user_id {
      favorites = CommonEngine::Favorite.arel_table
      join_condition = arel_table
                        .join(favorites, Arel::Nodes::OuterJoin).on(
                          Arel::Nodes::And.new([
                            arel_table[:id].eq(favorites[:idle_id]),
                            favorites[:user_id].eq(user_id),
                            favorites[:valid_flg].eq(false)])).join_sources
      joins(join_condition).select('favorites.*, idles.*')
    }

    enum gender: {female: 0, male: 1, other: 9}
    enum blood_type: {a: 0, b: 1, o: 2, ab: 3}
    enum employee_type: {permanent_staff: 0, temporary_staff: 1}

    mount_uploader :icon, CommonEngine::ImageUploader
  end
end
