module CommonEngine
  class Schedule < ApplicationRecord
    default_scope -> {where(valid_flg: false)}
    scope :search_with_idle_id_is_null, -> {arel_table[:idle_id].eq(nil)}

    belongs_to :idle, class_name: 'CommonEngine::Idle', primary_key: 'id', foreign_key: 'idle_id', optional: true
    belongs_to :user, class_name: 'CommonEngine::User', primary_key: 'id', foreign_key: 'user_id', optional: true
    belongs_to :chapter, class_name: 'CommonEngine::Chapter', primary_key: 'id', foreign_key: 'chapter_id', optional: true
    belongs_to :event, class_name: 'CommonEngine::Event', primary_key: 'id', foreign_key: 'event_id', optional: true

    enum category: {participate_event: 0, lesson: 1, personal_reasons: 2, self_study: 3}

    attribute :category_text, :string
    attribute :title, :string

    def set_category_text
      self.category_text = I18n.t('activerecord.schedules.categories.' + self.category.to_s)
      return self
    end
    def set_title
      self.set_category_text
      if self.chapter.present? && self.chapter.course.present?
        self.title = self.category_text + "\n" + self.chapter.course.name + "\n" + self.chapter.name
      elsif self.event.present?
        self.title = self.category_text + "\n" + self.event.name
      else
        self.title = self.category_text
      end
      return self
    end
  end
end
